C
C------------------------------------------------------
C
C     Problem:    ACETYL_Z
C
C     Date:       6.06.1997
C
C------------------------------------------------------
C
*     SET OF INDICES
      IND8=1..8
      IND9=1..9
      IND20=1..20
C
C------------------------------------------------------
C
*     REAL CONSTANT
      TEMP_SCALE=1E+3
      C_SCALE=1E-4
      AINI=0.1
      AMIN=0.0001
      R=8.314
      E1=2.7E+4
      E2=3.8E+4
      E3=3.4E+4
      E4=3.2E+4
      E5=3.0E+4
      TEMPR=873.15
      TEMP0=873.15
      TEMP_CTRL=873
      A1=0.72
      A2=0.56
      RHO0=47.02E-3
      EPS=0.999
      DH1=-263.0E+3
      DH2=277.5E+3
      DH3=283.0E+3
      DH4=226.7E+3
      DH5=241.8E+3
      BETA=1.4E-5
      K1=1.80E+04
      K2=9.00E+06
      K3=2.60E+05
      K4=8.90E+02
      K5=3.60E+04
C
C------------------------------------------------------
C
*     TABLE MM(I), I IN IND8
      1  16.0
      2  32.0
      3  26.0
      4  44.0
      5   2.0
      6  28.0
      7  18.0
      8 114.0
C
*     TABLE CPK(I), I IN IND8
      1  2.219
      2  0.917
      3  1.683
      4  0.837
      5  14.32
      6  1.042
      7  2.5
      8  1.595
C
*     TABLE PRICE(I), I IN IND8
      1  0.23
      2  0.053
      3  1.9
      4  0.0
      5  0.044
      6  0.044
      7  0.0
      8  0.1
C
C------------------------------------------------------
C
C   - Independent variables in the following order:
C     1. parameters to be estimated (p)
C     2. variables identifying solution of partial
C        differential equations (u)
C     3. variables identifying first space derivatives of
C        solution of partial differential equations (ux)
C     4. variables identifying second space derivatives of
C        solution of partial differential equations (uxx)
C     5. variables identifying solution of coupled
C        ordinary differential equations (v)
C     6. space variable (x)
C     7. time variable (t)
C
*     VARIABLE
      C1_CTRL, C2_CTRL
      C(I), I IN IND9
      A
      CT(I), I IN IND9
      AT
      CTT(I), I IN IND9
      ATT
      T, Z
C
C------------------------------------------------------
C
C   - Functions defining right-hand side of system of 
C     partial differential equations (order: functions in
C     first area, functions in second area, etc.):
C
*     FUNCTION CP1
      MP=C1_CTRL+C2_CTRL
      TEMP=C(9)*TEMP_SCALE
      SUM1=SUM(C(I)*C_SCALE*MM(I)*CPK(I), I IN IND8)
      SUM2=SUM(C(I)*C_SCALE*MM(I), I IN IND8)
      IF (SUM2.LE.0) THEN
        CPZT=1.
        RHO=0.00000001
      ELSE
        CPZT=SUM1/SUM2
        RHO=SUM2 
      ENDIF
C
      A11=A
      IF (A11.LE.0) THEN
        A11=0.00000001
      ENDIF
      V=MP/(RHO*A11)
      IF (C(1).GT.0) THEN
        C11=(C(1)*C_SCALE)**A1
      ELSE
        IF (C(1).LT.0) THEN
          C11=(-C(1)*C_SCALE)**A1
        ELSE
          C11=0
        ENDIF
      ENDIF
      IF (C(2).GT.0) THEN
        C21=(C(2)*C_SCALE)**A2
        C22=(C(2)*C_SCALE)**0.5
      ELSE
        IF (C(2).LT.0) THEN
          C21=(-C(2)*C_SCALE)**A2
          C22=(-C(2)*C_SCALE)**0.5
        ELSE
          C21=0
          C22=0
        ENDIF
      ENDIF
      IF (C(3).GT.0) THEN
        C31=(C(3)*C_SCALE)**A2
      ELSE
        IF (C(3).LT.0) THEN
          C31=(-C(3)*C_SCALE)**A2
        ELSE
          C31=0
        ENDIF
      ENDIF
      R1=K1*DEXP(-E1/R*(1.0/TEMP - 1.0/TEMPR))*C11
      R2=K2*DEXP(-E2/R*(1.0/TEMP - 1.0/TEMPR))*C(1)*C_SCALE*C21
      R3=K3*DEXP(-E3/R*(1.0/TEMP - 1.0/TEMPR))*C(6)*C_SCALE*C22
      R4=K4*DEXP(-E4/R*(1.0/TEMP - 1.0/TEMPR))*C31
      R5=K5*DEXP(-E5/R*(1.0/TEMP - 1.0/TEMPR))*C(5)*C_SCALE*C22
      CP1=(-R1 - R2)/V/C_SCALE
C
*     FUNCTION CP2
      CP2=(-R2 - 0.5*R3 - 0.5*R5)/V/C_SCALE
C
*     FUNCTION CP3
      CP3=(0.5*R1 - R4)/V/C_SCALE
C
*     FUNCTION CP4
      CP4=R3/V/C_SCALE
C
*     FUNCTION CP5
      CP5=(1.5*R1 + R2  + R4 - R5)/V/C_SCALE
C
*     FUNCTION CP6
      CP6=(R2 - R3)/V/C_SCALE
C
*     FUNCTION CP7
      CP7=(R2 + R5)/V/C_SCALE
C
*     FUNCTION CP8
      CP8=2.0*(1.0 - EPS)*R4/V/C_SCALE
C
*     FUNCTION CP9
      CP9=(R1*DH1 + R2*DH2 + R3*DH3
     /              + R4*DH4 + R5*DH5)/(RHO*V*CPZT)/TEMP_SCALE
C
*     FUNCTION ALG_EQU
      IF (C(3).GT.0) THEN
        C31=(C(3)*C_SCALE)**A2
      ELSE
        IF (C(3).LT.0) THEN
          C31=(-C(3)*C_SCALE)**A2
        ELSE
          C31=0
        ENDIF
      ENDIF
      TEMP=C(9)*TEMP_SCALE
      R4=K4*DEXP(-E4/R*(1.0/TEMP - 1.0/TEMPR))*C31
      ALG_EQU=(AT + BETA*R4)
C
C------------------------------------------------------
C
C   - Initial values of system of partial differential
C     equations for t=0 (order: functions in
C     first area, functions in second area, etc.):
C
*     FUNCTION C1_0
      MP=C1_CTRL+C2_CTRL
      C1_0 = C1_CTRL*RHO0/(MP*MM(1))/C_SCALE
C
*     FUNCTION C2_0
      C2_0 = C2_CTRL*RHO0/(MP*MM(2))/C_SCALE
C
*     FUNCTION C3_0
      C3_0 = 0.0
C
*     FUNCTION C4_0
      C4_0 = 0.0
C
*     FUNCTION C5_0
      C5_0 = 0.0
C
*     FUNCTION C6_0
      C6_0 = 0.0
C
*     FUNCTION C7_0
      C7_0 = 0.0
C
*     FUNCTION C8_0
      C8_0 = 0.0
C
*     FUNCTION C9_0
      C9_0 = TEMP_CTRL/TEMP_SCALE
C
*     FUNCTION A_0
      A_0=AINI
C
C------------------------------------------------------
C
C   - Boundary and transition functions first at left
C     borders of all areas, then at right borders of all 
C     areas:
C
*     FUNCTION AT_0
      AT_0=AINI
C
C------------------------------------------------------
C
C   - Fitting criteria:
C
*     FUNCTION PROFIT(J), J IN IND20
      SUM2=SUM(C(I)*C_SCALE*MM(I), I IN IND8)
      IF (SUM2.LE.0) THEN
        RHO=0.00000001
      ELSE
        RHO=SUM2 
      ENDIF
      MP=C1_CTRL+C2_CTRL
      PROFIT(J) = SUM(PRICE(I)*C(I)*C_SCALE*MM(I), I IN IND8)*MP/RHO 
     /          - PRICE(1)*C1_CTRL - PRICE(2)*C2_CTRL
C
C------------------------------------------------------
C
C   - Constraints:
C
*     FUNCTION G(I), I IN IND9
      G(I) = A - AMIN
C
C------------------------------------------------------
C
*     END
C
C------------------------------------------------------
C
