C
C------------------------------------------------------
C
C     Problem:    BURGER
C
C     Date:       10.8.1996
C 
C------------------------------------------------------
C
*     SET OF INDICES
      IND=1..4
C
C------------------------------------------------------
C
C   - Independent variables in the following order:
C     1. parameters to be estimated (p)
C     2. variables identifying solution of partial
C        differential equations, first the differential ones,
C        then the algebraic variables (u)
C     3. variables identifying first spatial derivatives of
C        solution of partial differential equations (u_x)
C     4. variables identifying second spatial derivatives of
C        solution of partial differential equations (u_xx)
C     5. variables identifying solution of coupled
C        ordinary differential equations (v)
C     6. variables for flux functions, if available (one
C        variable for each function (f), then one for
C        each derivative (f_x). These names can be
C        inserted subsequently. Note that flux variables
C        must be declared for each PDE equation, if at all.
C     7. spatial variable (x)
C     8. time variable (t)
C
*     VARIABLE
      D, u, u_x, u_xx, f, f_x, x, t
C
C------------------------------------------------------
C
C   - Functions defining the flux depending on u and u_x,
C     if available (order: functions in first area, func-
C     tions in second area, etc.):
C
*     FUNCTION flux
      flux = D*u_x - 0.5*u**2
C
C------------------------------------------------------
C
C   - Functions defining right-hand side of system of 
C     partial differential equations (order: differential
C     followed by algebraic functions in first area, then
C     differential followed by algebraic functions in 
C     second area, etc.):
C
*     FUNCTION u_t
      u_t = f_x
C
C------------------------------------------------------
C
C   - Initial values of system of partial differential
C     equations for t=0 (order: initial values for 
C     differential followed by algebraic variables in 
C     first area, then differential followed by algebraic
C     variables in second area, etc.):
C
*     FUNCTION u_0
      a = (x - 0.5)/(20*D)
      b = (x - 0.5)/(4*D)
      c = (x - 0.375)/(2*D) 
      u_0 = (0.1*exp(-a) + 0.5*exp(-b) + exp(-c))
     /         /(exp(-a) + exp(-b) + exp(-c))
C
C------------------------------------------------------
C
C   - Functions defining right-hand side of system of 
C     coupled ordinary differential equations:
C
C*     FUNCTION VP
C      VP = ...
C
C------------------------------------------------------
C
C   - Initial values of system of coupled ordinary
C     differential equations for t=0: 
C
C*     FUNCTION V0
C      V0 = ...
C
C------------------------------------------------------
C
C   - Boundary and transition functions first at left
C     borders of all areas, then at right borders of all 
C     areas:
C
*     FUNCTION u_l
      a = (x - 0.5 + 4.95*t)/(20*D)
      b = (x - 0.5 + 0.75*t)/(4*D)
      c = (x - 0.375)/(2*D) 
      u_l = (0.1*exp(-a) + 0.5*exp(-b) + exp(-c))
     /         /(exp(-a) + exp(-b) + exp(-c))
C
*     FUNCTION u_r
      a = (x - 0.5 + 4.95*t)/(20*D)
      b = (x - 0.5 + 0.75*t)/(4*D)
      c = (x - 0.375)/(2*D) 
      u_r = (0.1*exp(-a) + 0.5*exp(-b) + exp(-c))
     /         /(exp(-a) + exp(-b) + exp(-c))
C
C------------------------------------------------------
C
C   - Fitting criteria:
C
*     FUNCTION u_fit(i), i IN IND
c      a = (x - 0.5 + 4.95*t)/(20*D)
c      b = (x - 0.5 + 0.75*t)/(4*D)
c      c = (x - 0.375)/(2*D) 
c      u_fit(i)= (0.1*exp(-a) + 0.5*exp(-b) + exp(-c))
c     /         /(exp(-a) + exp(-b) + exp(-c))
      u_fit(i) = u
C
C------------------------------------------------------
C
C   - Constraints (if exist):
C
C*     FUNCTION G1
C      G1 = ...
C
C------------------------------------------------------
C
*     END
C
C------------------------------------------------------
C






